@@ -1,6 +1,6 @@
 from .exporter import init_otlp_exporter, send_to_otel
 from .sqs_fallback import init_sqs_fallback, send_fallback
-from .decorators import trace
+from .decorators import trace_span
 from .tracer import start_trace, end_trace, start_span, end_span
 
 __all__ = [
@@ -8,7 +8,7 @@ __all__ = [
     "init_sqs_fallback",
     "send_fallback",
     "send_to_otel",
-    "trace",
+    "trace_span",
     "start_trace",
     "end_trace",
     "start_span",
